/*
 * jkeytool - CoreListener.java -
 * Copyright © 2009 David Roden
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package net.pterodactylus.jkeytool.core;

import java.io.File;
import java.security.KeyStore;
import java.util.EventListener;

/**
 * Listener interface for {@link Core} events.
 *
 * @author David Roden &lt;droden@gmail.com&gt;
 */
public interface CoreListener extends EventListener {

	/**
	 * Notifies all listener that a new key store was created.
	 *
	 * @param keyStore
	 *            The key store that was created
	 */
	public void keyStoreCreated(KeyStore keyStore);

	/**
	 * Notifies all listeners that a key store of the given type could not be
	 * created.
	 *
	 * @param keyStoreType
	 *            The type of the key store that should be created
	 * @param reason
	 *            The reason why the key store could not be created
	 */
	public void keyStoreNotCreated(String keyStoreType, Throwable reason);

	/**
	 * Notifies all listeners that a key store was loaded from a file.
	 *
	 * @param keyStoreFile
	 *            The key store file
	 * @param keyStore
	 *            The loaded key store
	 */
	public void keyStoreLoaded(File keyStoreFile, KeyStore keyStore);

	/**
	 * Notifies all listeners that a key store file could not be loaded.
	 *
	 * @param keyStoreFile
	 *            The key store file
	 */
	public void keyStoreNotLoaded(File keyStoreFile);

}
